@@ -1,6 +1,6 @@
 /*
  * main.c
- * Copyright 2005-2013 George Averill, William Pitcock, Yoshiki Yazawa, and
+ * Copyright 2005-2013 George Averill, Ariadne Conill, Yoshiki Yazawa, and
  *                     John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
@@ -66,7 +66,9 @@ const struct commandhandler handlers[] =
     {"select-displayed", select_displayed, "apply commands to displayed playlist", 0},
     {"select-playing", select_playing, "apply commands to playing playlist", 0},
     {"playlist-advance", playlist_advance, "skip to next song", 0},
+    {"playlist-advance-album", playlist_advance_album, "skip to next album", 0},
     {"playlist-reverse", playlist_reverse, "skip to previous song", 0},
+    {"playlist-reverse-album", playlist_reverse_album, "skip to beginning of the previous album", 0},
     {"playlist-addurl", playlist_add_url_string, "add URI at end of playlist", 1},
     {"playlist-insurl", playlist_ins_url_string, "insert URI at given position", 2},
     {"playlist-addurl-to-new-playlist", playlist_enqueue_to_temp, "open URI in \"Now Playing\" playlist", 1},
@@ -222,9 +224,7 @@ int main (int argc, char * * argv)
 
     setlocale (LC_CTYPE, "");
 
-#if ! GLIB_CHECK_VERSION (2, 36, 0)
     g_type_init();
-#endif
 
 #ifdef _WIN32
     g_set_print_handler (print_utf8);
