@@ -1,6 +1,6 @@
 /*
- * util.cc
- * Copyright 2014 Ariadne Conill
+ * audqt.cc
+ * Copyright 2014-2021 Ariadne Conill and John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -20,8 +20,12 @@
 #include <stdlib.h>
 
 #include <QApplication>
-#include <QDesktopWidget>
+#include <QLibraryInfo>
+#include <QProxyStyle>
 #include <QPushButton>
+#include <QScreen>
+#include <QStyleFactory>
+#include <QTranslator>
 #include <QVBoxLayout>
 
 #include <libaudcore/audstrings.h>
@@ -42,34 +46,96 @@ static PixelMargins margins_local;
 EXPORT const PixelSizes & sizes = sizes_local;
 EXPORT const PixelMargins & margins = margins_local;
 
+/* clang-format off */
+static const char * const audqt_defaults[] = {
+    "eq_presets_visible", "FALSE",
+    "equalizer_visible", "FALSE",
+    "queue_manager_visible", "FALSE",
+#ifdef _WIN32
+    "theme", "dark",
+    "icon_theme", "audacious-flat-dark",
+#endif
+    nullptr
+};
+/* clang-format on */
+
+static void load_qt_translations()
+{
+    static QTranslator translators[2];
+
+    QLocale locale = QLocale::system();
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QString dir = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+#else
+    QString dir = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+#endif
+
+    if (translators[0].load(locale, "qt", "_", dir))
+        QApplication::installTranslator(&translators[0]);
+    if (translators[1].load(locale, "qtbase", "_", dir))
+        QApplication::installTranslator(&translators[1]);
+}
+
+void set_icon_theme(void)
+{
+    QIcon::setThemeName((QString)aud_get_str("audqt", "icon_theme"));
+
+    // make sure we have a valid icon theme
+    auto isValid = [](QString theme) {
+        return !theme.isEmpty() && theme != "hicolor";
+    };
+
+    if (!isValid(QIcon::themeName()))
+    {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
+        QString fallback = QIcon::fallbackThemeName();
+        if (isValid(fallback))
+            QIcon::setThemeName(fallback);
+        else
+#endif
+            QIcon::setThemeName("audacious-flat");
+    }
+
+    // add fallback icons just to be sure
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    auto paths = QIcon::fallbackSearchPaths();
+    auto path = ":/icons/audacious-flat/scalable";
+    if (!paths.contains(path))
+        QIcon::setFallbackSearchPaths(paths << path);
+#endif
+
+    qApp->setWindowIcon(QIcon::fromTheme("audacious"));
+}
+
 EXPORT void init()
 {
     if (init_count++)
         return;
 
+    aud_config_set_defaults("audqt", audqt_defaults);
+
     static char app_name[] = "audacious";
     static int dummy_argc = 1;
     static char * dummy_argv[] = {app_name, nullptr};
 
     auto qapp = new QApplication(dummy_argc, dummy_argv);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     qapp->setAttribute(Qt::AA_UseHighDpiPixmaps);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
-    qapp->setAttribute(Qt::AA_ForceRasterWidgets);
-#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    qapp->setAttribute(Qt::AA_DisableWindowContextHelpButton);
+#endif // >= 5.10
+#endif // < 6.0
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     qapp->setAttribute(Qt::AA_UseStyleSheetPropagationInWidgetStyles);
 #endif
 
     qapp->setApplicationName(_("Audacious"));
-    if (qapp->windowIcon().isNull())
-        qapp->setWindowIcon(audqt::get_icon(app_name));
-
     qapp->setQuitOnLastWindowClosed(false);
 
-    auto desktop = qapp->desktop();
     sizes_local.OneInch =
-        aud::max(96, (desktop->logicalDpiX() + desktop->logicalDpiY()) / 2);
+        aud::max(96, (int)qapp->primaryScreen()->logicalDotsPerInch());
     sizes_local.TwoPt = aud::rescale(2, 72, sizes_local.OneInch);
     sizes_local.FourPt = aud::rescale(4, 72, sizes_local.OneInch);
     sizes_local.EightPt = aud::rescale(8, 72, sizes_local.OneInch);
@@ -81,6 +147,19 @@ EXPORT void init()
     margins_local.EightPt =
         QMargins(sizes.EightPt, sizes.EightPt, sizes.EightPt, sizes.EightPt);
 
+    load_qt_translations();
+    set_icon_theme();
+
+    if (!strcmp(aud_get_str("audqt", "theme"), "dark"))
+        enable_dark_theme();
+
+#ifdef _WIN32
+    // On Windows, Qt uses 9 pt in specific places (such as QMenu) but
+    // 8 pt as the application font, resulting in an inconsistent look.
+    // First-party Windows applications (and GTK applications too) seem
+    // to use 9 pt in most places so let's try to do the same.
+    QApplication::setFont(QApplication::font("QMenu"));
+#endif
 #ifdef Q_OS_MAC // Mac-specific font tweaks
     QApplication::setFont(QApplication::font("QSmallFont"), "QDialog");
     QApplication::setFont(QApplication::font("QSmallFont"), "QTreeView");
@@ -100,14 +179,11 @@ EXPORT void cleanup()
         return;
 
     aboutwindow_hide();
-    eq_presets_hide();
-    equalizer_hide();
     infopopup_hide_now();
     infowin_hide();
     log_inspector_hide();
     plugin_prefs_hide();
     prefswin_hide();
-    queue_manager_hide();
 
     log_cleanup();
 
@@ -116,12 +192,7 @@ EXPORT void cleanup()
 
 EXPORT QIcon get_icon(const char * name)
 {
-    auto icon = QIcon::fromTheme(name);
-
-    if (icon.isNull())
-        icon = QIcon(QString(":/") + name + ".svg");
-
-    return icon;
+    return QIcon::fromTheme(name);
 }
 
 EXPORT QGradientStops dark_bg_gradient(const QColor & base)
@@ -149,7 +220,7 @@ EXPORT QGradientStops dark_bg_gradient(const QColor & base)
 
 EXPORT QColor vis_bar_color(const QColor & hue, int bar, int n_bars)
 {
-    qreal h, s, v;
+    decltype(hue.hueF()) h, s, v;
     hue.getHsvF(&h, &s, &v);
 
     if (s < 0.1) /* monochrome? use blue instead */
@@ -177,6 +248,19 @@ EXPORT QVBoxLayout * make_vbox(QWidget * parent, int spacing)
     return layout;
 }
 
+EXPORT void setup_proxy_style(QProxyStyle * style)
+{
+    // set the correct base style ("fusion" or native)
+    if (!strcmp(aud_get_str("audqt", "theme"), "dark"))
+        style->setBaseStyle(QStyleFactory::create("fusion"));
+    else
+        style->setBaseStyle(nullptr);
+
+    // detect and respond to application-wide style change
+    QObject::connect(qApp->style(), &QObject::destroyed, style,
+                     [style]() { setup_proxy_style(style); });
+}
+
 EXPORT void enable_layout(QLayout * layout, bool enabled)
 {
     int count = layout->count();
