@@ -73,10 +73,20 @@ EXPORT void fileopener_show(FileMode mode)
 
         dialog->setAttribute(Qt::WA_DeleteOnClose);
         dialog->setFileMode(modes[mode]);
+        if (modes[mode] == QFileDialog::FileMode::Directory)
+            dialog->setOption(QFileDialog::ShowDirsOnly);
         dialog->setLabelText(QFileDialog::Accept, _(labels[mode]));
+        dialog->setLabelText(QFileDialog::Reject, _("Cancel"));
+
+        auto playlist = Playlist::active_playlist();
 
         if (mode == FileMode::ExportPlaylist)
+        {
             dialog->setAcceptMode(QFileDialog::AcceptSave);
+            String filename = playlist.get_filename();
+            if (filename)
+                dialog->selectUrl(QString(filename));
+        }
 
         QObject::connect(dialog.data(), &QFileDialog::directoryEntered,
                          [](const QString & path) {
@@ -84,8 +94,6 @@ EXPORT void fileopener_show(FileMode mode)
                                          path.toUtf8().constData());
                          });
 
-        auto playlist = Playlist::active_playlist();
-
         QObject::connect(
             dialog.data(), &QFileDialog::accepted, [dialog, mode, playlist]() {
                 Index<PlaylistAddItem> files;
