@@ -67,8 +67,9 @@ public:
 protected:
     int rowCount(const QModelIndex & parent = QModelIndex()) const
     {
-        return m_entries.len();
+        return parent.isValid() ? 0 : m_entries.len();
     }
+
     int columnCount(const QModelIndex & parent = QModelIndex()) const
     {
         return LogEntryColumn::Count;
@@ -234,7 +235,7 @@ LogEntryInspector::LogEntryInspector(QWidget * parent) : QDialog(parent)
 
     auto btn1 = btnbox->addButton(translate_str(N_("Cl_ear")),
                                   QDialogButtonBox::ActionRole);
-    btn1->setIcon(audqt::get_icon("edit-clear-all"));
+    btn1->setIcon(QIcon::fromTheme("edit-clear-all"));
     btn1->setAutoDefault(false);
     QObject::connect(btn1, &QPushButton::clicked,
                      []() { s_model.get()->cleanup(); });
