@@ -21,6 +21,7 @@
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QLabel>
+#include <QPointer>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -66,7 +67,7 @@ static QDialog * buildUrlDialog(bool open)
 
     auto clear_button =
         new QPushButton(translate_str(N_("C_lear history")), dialog);
-    clear_button->setIcon(audqt::get_icon("edit-clear"));
+    clear_button->setIcon(QIcon::fromTheme("edit-clear"));
 
     auto hbox = make_hbox(nullptr);
     prefs_populate(hbox, widgets, PACKAGE);
@@ -74,10 +75,10 @@ static QDialog * buildUrlDialog(bool open)
     hbox->addWidget(clear_button);
 
     auto button1 = new QPushButton(translate_str(verb), dialog);
-    button1->setIcon(audqt::get_icon(icon));
+    button1->setIcon(QIcon::fromTheme(icon));
 
     auto button2 = new QPushButton(translate_str(N_("_Cancel")), dialog);
-    button2->setIcon(audqt::get_icon("process-stop"));
+    button2->setIcon(QIcon::fromTheme("process-stop"));
 
     auto buttonbox = new QDialogButtonBox(dialog);
     buttonbox->addButton(button1, QDialogButtonBox::AcceptRole);
@@ -126,7 +127,7 @@ static QDialog * buildUrlDialog(bool open)
     return dialog;
 }
 
-static QDialog * s_dialog = nullptr;
+static QPointer<QDialog> s_dialog;
 
 EXPORT void urlopener_show(bool open)
 {
@@ -134,9 +135,6 @@ EXPORT void urlopener_show(bool open)
     {
         s_dialog = buildUrlDialog(open);
         s_dialog->setAttribute(Qt::WA_DeleteOnClose);
-
-        QObject::connect(s_dialog, &QObject::destroyed,
-                         []() { s_dialog = nullptr; });
     }
 
     window_bring_to_front(s_dialog);
